from django.http import JsonResponse
from ohm2_handlers_light.parsers import get_as_or_get_default
from rest_framework.authentication import TokenAuthentication
from rest_framework.decorators import api_view, authentication_classes, permission_classes
from rest_framework.permissions import IsAuthenticated
from . import dispatcher


@api_view(['POST'])
@authentication_classes((TokenAuthentication,))
@permission_classes((IsAuthenticated,))
def create_crontab_job_get_data_charge_controller(request):
    keys = (
        ("minutes_frecuency","minutes_frecuency",0),
    )
    print("request.data create_crontab_job_get_data_charge_controller: ", request.data)
    res, error = dispatcher.create_crontab_job_get_data_charge_controller(request, get_as_or_get_default(request.data, keys))
    if error:
        print("ERROR ORIGINAL create_crontab_job_get_data_charge_controller ", error.original)
        return JsonResponse({"error": error.regroup()})
    return JsonResponse(res)



from django import VERSION as DJANGO_VERSION

if DJANGO_VERSION >= (2, 0):
	from django.urls import include, path, re_path as url
else:
	from django.conf.urls import include, url

from . import views

app_name = "matialvarezs_charge_controller"

urlpatterns = [
	url(r'^matialvarezs_charge_controller/$', views.index, name = 'index'),
	url('api/', include('matialvarezs_charge_controller.api.urls', namespace='api')),
]





from ohm2_handlers_light.decorators import ohm2_handlers_light_safe_request

def matialvarezs_charge_controller_safe_request(function):
	return ohm2_handlers_light_safe_request(function, "matialvarezs_charge_controller")



from django.core.management.base import BaseCommand, CommandError
from ohm2_handlers_light import utils as h_utils
from matialvarezs_charge_controller import utils as matialvarezs_charge_controller_utils,settings
import os
from django.utils import timezone
from matialvarezs_charge_controller.github import registers, client
from matialvarezs_request_handler import utils as matialvarezs_request_handler_utils
from matialvarezs_node_configurations import utils as matialvarezs_node_configurations_utils

class Command(BaseCommand):
    def add_arguments(seTlf, parser):
        pass  # parser.add_argument('-f', '--foo')

    def handle(self, *args, **options):
        # foo = options["foo"]
        commands = matialvarezs_charge_controller_utils.filter_registers_data()
        clc = client.EPsolarTracerClient()
        clc.connect()
        data = {
            'datetime':str(timezone.now()),
            'node_identity':matialvarezs_node_configurations_utils.get_identity()
        }
        print("DATA ANTES DE PROCESAR",data)
        for item in commands:

            # reg = registers.Register(name='', address=int(item.address, 16), description='', unit=item.unit,
            #                          times=item.times)
            #print("item.is_coil(),item.is_discrete_input(),item.is_input_register(),item.is_holding_register()",item.is_coil(),item.is_discrete_input(),item.is_input_register(),item.is_holding_register())
            print(item.code, ' - ', int(item.address), '- ', clc.read_input(item).value,' - ',item.bits)
            if item.code == "batery_current_charge":
                data[item.code] = int(clc.read_input(item).value)
            else:
                data[item.code] = float(clc.read_input(item).value)

        try:

            res = matialvarezs_request_handler_utils.send_get_and_get_response(settings.MATIALVAREZS_CHARGE_CONTROLLER_CREATE_DATA_CHARGE_CONTROLLER_URL, data=data)
            if res['error'] and res['error'] is not None:
                matialvarezs_charge_controller_utils.create_local_data_backup(data=data, send_to_server=True)
            print("RES ALMACENAMIENTO EN SERVIDOR AWS: ", res)
        except Exception as e:
            print("ERROR AL OBTENER DATOS CONTROLADOR DE CARGA: ", str(timezone.now()), e)



# import the server implementation
from pymodbus.client.sync import ModbusSerialClient as ModbusClient,ModbusTcpClient
from pymodbus.mei_message import *
#from registers import registerByName


#---------------------------------------------------------------------------#
# Logging
#---------------------------------------------------------------------------#
import logging
_logger = logging.getLogger(__name__)

class EPsolarTracerClient:
    ''' EPsolar Tracer client
    '''

    def __init__(self, unit = 1, serialclient = None, **kwargs):
        ''' Initialize a serial client instance
        '''
        self.unit = unit
        if serialclient == None:
            port = kwargs.get('port', '/dev/ttyUSB1')
            baudrate = kwargs.get('baudrate', 115200)
            self.client = ModbusTcpClient('192.168.130.10', port=26)#ModbusClient(method = 'rtu', port = port, baudrate = baudrate, kwargs = kwargs)

        else:
            self.client = serialclient

    def connect(self):
        ''' Connect to the serial
        :returns: True if connection succeeded, False otherwise
        '''
        return self.client.connect()

    def close(self):
        ''' Closes the underlying connection
        '''
        return self.client.close()

    def read_device_info(self):
        request = ReadDeviceInformationRequest (unit = self.unit)
        response = self.client.execute(request)
        return response

    def read_input(self, register):
        #register = registerByName(name)
        if register.bits:
            response = self.client.read_discrete_inputs(register.address, register.count, unit = self.unit)
            return register.decode_bits(response)
        elif register.is_coil():
            response = self.client.read_coils(register.address, register.count, unit = self.unit)
        elif register.is_discrete_input():
            response = self.client.read_discrete_inputs(register.address, register.count, unit = self.unit)

        elif register.is_input_register():
            response = self.client.read_input_registers(register.address, register.count, unit = self.unit)
        else:
            response = self.client.read_holding_registers(register.address, register.count, unit = self.unit)
        return register.decode(response)

    def write_output(self, register, value):
        #register = registerByName(name)
        values = register.encode(value)
        response = False
        if register.is_coil():
            self.client.write_coil(register.address, values, unit = self.unit)
            response = True
        elif register.is_discrete_input():
            _logger.error("Cannot write discrete input " + repr(register.name))
            pass
        elif register.is_input_register():
            _logger.error("Cannot write input register " + repr(register.name))
            pass
        else:
            self.client.write_registers(register.address, values, unit = self.unit)
            response = True
        return response



from django.core.exceptions import ObjectDoesNotExist
from django.contrib.auth.models import User
from django.utils import timezone
from django.utils.translation import ugettext as _
from django.db.models import Q
from ohm2_handlers_light import utils as h_utils
from ohm2_handlers_light.definitions import RunException
from . import models as matialvarezs_charge_controller_models
from . import errors as matialvarezs_charge_controller_errors
from . import settings
import os, time, random


random_string = "NzmXq9jLxGJGyDFHrj4F07d97F284t7j"



"""
def parse_model_attributes(**kwargs):
	attributes = {}
	
	return attributes

def create_model(**kwargs):

	for key, value in parse_model_attributes(**kwargs).items():
		kwargs[key] = value
	return h_utils.db_create(matialvarezs_charge_controller_models.Model, **kwargs)

def get_model(**kwargs):
	return h_utils.db_get(matialvarezs_charge_controller_models.Model, **kwargs)

def get_or_none_model(**kwargs):
	return h_utils.db_get_or_none(matialvarezs_charge_controller_models.Model, **kwargs)

def filter_model(**kwargs):
	return h_utils.db_filter(matialvarezs_charge_controller_models.Model, **kwargs)

def q_model(q, **otions):
	return h_utils.db_q(matialvarezs_charge_controller_models.Model, q)

def delete_model(entry, **options):
	return h_utils.db_delete(entry)

def update_model(entry, **kwargs):
	attributes = {}
	for key, value in parse_model_attributes(**kwargs).items():
		attributes[key] = value
	return h_utils.db_update(entry, **attributes)
"""

def create_local_data_backup(**kwargs):
    return h_utils.db_create(matialvarezs_charge_controller_models.LocalDataBackup, **kwargs)


def filter_local_data_backup(**kwargs):
    return h_utils.db_filter(matialvarezs_charge_controller_models.LocalDataBackup, **kwargs)

def filter_registers_data(**kwargs):
    return h_utils.db_filter(matialvarezs_charge_controller_models.RegistersData, **kwargs)

def create_registers_data(**kwargs):
    return h_utils.db_create(matialvarezs_charge_controller_models.RegistersData, **kwargs)


# Generated by Django 2.2.4 on 2019-08-16 16:04

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('matialvarezs_charge_controller', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='LocalDataBackup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField()),
                ('send_to_server', models.BooleanField(default=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 2.2.4 on 2019-08-16 04:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RegistersData',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identity', models.CharField(max_length=2048, unique=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now)),
                ('last_update', models.DateTimeField(default=django.utils.timezone.now)),
                ('address', models.IntegerField(default=0)),
                ('code', models.CharField(default='', max_length=512)),
                ('count', models.IntegerField(default=1)),
                ('times', models.IntegerField(default=1)),
                ('unit', models.IntegerField(default=1)),
                ('function_code', models.IntegerField(default=0)),
                ('bits', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: iso-8859-15 -*-
#
# From the PDF

# ---------------------------------------------------------------------------#
# Logging
# ---------------------------------------------------------------------------#
import logging

_logger = logging.getLogger(__name__)


def V():
    return ['Voltage', 'V']


def A():
    return ['Ampere', 'A']


def AH():
    return ['Ampere hours', 'Ah']


def W():
    return ['Watt', 'W']


def C():
    return ['degree Celsius', '°C']  # \0xb0


def PC():
    return ['%, percentage', '%']


def KWH():
    return ['kWh, kiloWatt/hour', 'kWh']


def Ton():
    return ['1000kg', 't']


def MO():
    return ['milliohm', 'mOhm']


def I():
    return ['integer', '']


def SEC():
    return ['seconds', 's']


def MIN():
    return ['minutes', 'min']


def HOUR():
    return ['hours', 'h']


class Value:
    '''Value with unit'''

    def __init__(self, register, value):
        self.register = register
        if self.register.times != 1 and value is not None:
            self.value = 1.0 * value / self.register.times
        else:
            self.value = value

    def __str__(self):
        if self.value is None:
            return self.register.name + " = " + str(self.value)
        return self.register.name + " = " + str(self.value) + self.register.unit()[1]

    def __float__(self):
        return float(self.value)

    def __int__(self):
        return int(self.value)


class Register:
    def __init__(self, name, address, description, unit, times, size=1,code=""):
        self.name = name
        self.address = address
        self.description = description
        self.unit = unit
        self.times = times
        self.size = size
        self.code = code
    def is_coil(self):
        return self.address < 0x1000

    def is_discrete_input(self):
        return self.address >= 0x1000 and self.address < 0x3000

    def is_input_register(self):
        return self.address >= 0x3000 and self.address < 0x9000

    def is_holding_register(self):
        return self.address >= 0x9000

    def decode(self, response):
        if hasattr(response, "getRegister"):
            mask = rawvalue = lastvalue = 0
            for i in range(self.size):
                lastvalue = response.getRegister(i)
                rawvalue = rawvalue | (lastvalue << (i * 16))
                mask = (mask << 16) | 0xffff
            if (lastvalue & 0x8000) == 0x8000:
                # print rawvalue
                rawvalue = -(rawvalue ^ mask) - 1
            return Value(self, rawvalue)
        _logger.info("No value for register " + repr(self.name))
        return Value(self, None)

    def encode(self, value):
        # FIXME handle 2 word registers
        rawvalue = int(value * self.times)
        if rawvalue < 0:
            rawvalue = (-rawvalue - 1) ^ 0xffff
            # print rawvalue
        return rawvalue


class Coil(Register):
    def decode(self, response):
        if hasattr(response, "bits"):
            return Value(self, response.bits[0])
        _logger.info("No value for coil " + repr(self.name))
        return Value(self, None)



from matialvarezs_charge_controller import utils as matialvarezs_charge_controller_utils
from matialvarezs_charge_controller import settings

def send_local_data_to_server():
    data = matialvarezs_charge_controller_utils.filter_local_data_backup(send_to_server=True)
    for item in data:
        res = send_requests.send_request(settings.MATIALVAREZS_CHARGE_CONTROLLER_CREATE_DATA_CHARGE_CONTROLLER_URL, data=item.data)
        if res['ret']:
            item.send_to_server = False
            item.save()



from django.core.management.base import BaseCommand, CommandError
from matialvarezs_charge_controller import resend_data_to_server
from matialvarezs_handlers_easy import utils as matialvarezs_handlers_easy_utils
from django.utils import timezone


class Command(BaseCommand):
    def add_arguments(self, parser):
        pass  # parser.add_argument('-f', '--foo')

    def handle(self, *args, **options):
        # foo = options["foo"]
        print("REVISION DATOS GUARDADOS LOCALMENTE PARA ENVIAR AL SERVIDOR EL: ",
              matialvarezs_handlers_easy_utils.datetime_utc_to_localtime(timezone.now(), 'America/Santiago'))
        resend_data_to_server.send_local_data_to_server()



from django.core.management.base import BaseCommand, CommandError
from matialvarezs_charge_controller import settings

from matialvarezs_handlers_easy import crontab_jobs_utils



class Command(BaseCommand):
    def add_arguments(self, parser):
        pass  # parser.add_argument('-f', '--foo')

    def handle(self, *args, **options):
        # foo = options["foo"]
        command = settings.SCRIPTS_PATH + 'charge_controller_delete_sent_local_data_to_server.sh >>' + settings.CRON_JOB_LOGS_PATH + 'charge_controller_delete_sent_local_data_to_server.log 2>&1'
        comment = ''
        if settings.PRODUCTION_CONFIG:
            comment = 'production_charge_controller_delete_sent_local_data_to_server'
        else:
            comment = 'development_charge_controller_delete_sent_local_data_to_server'
            crontab_jobs_utils.create_cron_execute_every_month(command=command, comment=comment)



from django.db import models
from django.contrib.postgres.fields import JSONField
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.core.validators import MinLengthValidator, MaxLengthValidator
from django.utils import timezone
from django.utils.translation import ugettext as _
from ohm2_handlers_light.models import BaseModel
from . import managers
from . import settings
from matialvarezs_charge_controller.github.registers import Value



"""
class Model(BaseModel):
	pass
"""
class LocalDataBackup(BaseModel):
    data = JSONField()
    send_to_server = models.BooleanField(default=True)

class RegistersData(BaseModel):
    address = models.IntegerField(default=0)
    code = models.CharField(default='', max_length=settings.STRING_NORMAL)
    count = models.IntegerField(default=1)
    times = models.IntegerField(default=1)
    unit = models.IntegerField(default=1)
    function_code = models.IntegerField(default=0)
    bits = models.BooleanField(default=False)

    def is_coil(self):
        return self.address < int(0x1000)

    def is_discrete_input(self):
        return self.address >= 0x1000 and self.address < 0x3000
        # return int(str(self.address)) >= int(0x1000) and int(str(self.address)) < int(0x3000)

    def is_input_register(self):
        return self.address >= 0x3000 and self.address < 0x9000

    def is_holding_register(self):
        return self.address >= 0x9000

    def decode(self, response):
        if hasattr(response, "getRegister"):
            mask = rawvalue = lastvalue = 0
            for i in range(self.count):
                lastvalue = response.getRegister(i)
                rawvalue = rawvalue | (lastvalue << (i * 16))
                mask = (mask << 16) | 0xffff
            if (lastvalue & 0x8000) == 0x8000:
                # print rawvalue
                rawvalue = -(rawvalue ^ mask) - 1
            return Value(self, rawvalue)
        # _logger.info("No value for register " + repr(self.name))
        return Value(self, None)

    def decode_bits(self, response):
        if hasattr(response, "bits"):
            return Value(self, response.bits[0])
        # _logger.info("No value for coil " + repr(self.name))
        return Value(self, None)

    def encode(self, value):
        # FIXME handle 2 word registers
        rawvalue = int(value * self.times)
        if rawvalue < 0:
            rawvalue = (-rawvalue - 1) ^ 0xffff
            # print rawvalue
        return rawvalue



from distutils.core import setup
import setuptools
setuptools.setup(
  name = 'matialvarezs_charge_controller',
  packages = setuptools.find_packages(),#['matialvarezs_charge_controller'], # this must be the same as the name above
  version = '0.0.122',
  install_requires = [
    'matialvarezs-handlers-easy==0.1.26',
    'matialvarezs_node_configurations==0.0.7',
    'matialvarezs-request-handler==0.1.6',
    'python-crontab==2.3.6'
  ],
  include_package_data = True,
  description = 'Charge controller data',
  author = 'Matias Alvarez Sabate',
  author_email = 'matialvarezs@gmail.com',  
  classifiers = [
    'Programming Language :: Python :: 3.5',
  ],
)


from django.core.management.base import BaseCommand, CommandError
from ohm2_handlers_light import utils as h_utils
from matialvarezs_charge_controller import utils as matialvarezs_charge_controller_utils
import os


class Command(BaseCommand):
    def add_arguments(self, parser):
        pass  # parser.add_argument('-f', '--foo')

    def handle(self, *args, **options):
        # foo = options["foo"]
        # charge_controller_utils.filter_registers_data().delete()
        # charge_controller_utils.create_registers_data(code='day_night', address='0x200C', count=1, unit=1,
        #                                               function_code=0x02,times=1)
        # charge_controller_utils.create_registers_data(code='temperature_inside_device', address='0x2000', count=1,
        #                                               unit=1, function_code=0x02,times=1)
        # charge_controller_utils.create_registers_data(code='pv_voltage_input', address='0x3100', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        #
        # charge_controller_utils.create_registers_data(code='pv_current_input', address='0x3101', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        #
        # charge_controller_utils.create_registers_data(code='pv_power_input', address='0x3102', count=2, unit=1,
        #                                               function_code=0x04,times=100)
        #
        # charge_controller_utils.create_registers_data(code='batery_voltage', address='0x331A', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='batery_current', address='0x331B', count=2, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='batery_current_charge', address='0x311A', count=1, unit=1,
        #                                               function_code=0x04,times=1)  # % de carga
        # charge_controller_utils.create_registers_data(code='batery_temperature', address='0x3110', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='load_voltage', address='0x310C', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='load_current', address='0x310D', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='load_power', address='0x310E', count=2, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='consumed_energy_today', address='0x3304', count=2, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='generated_energy_today', address='0x330C', count=2, unit=1,
        #                                               function_code=0x04,times=100)
        # charge_controller_utils.create_registers_data(code='device_temperature', address='0x3111', count=1, unit=1,
        #                                               function_code=0x04,times=100)
        matialvarezs_charge_controller_utils.filter_registers_data().delete()
        matialvarezs_charge_controller_utils.create_registers_data(code='day_night', address=0x200C, count=1, unit=1,
                                                                   function_code=0x02, times=1, bits=True)
        matialvarezs_charge_controller_utils.create_registers_data(code='temperature_inside_device', address=0x2000,
                                                                   count=1,
                                                                   unit=1, function_code=0x02, times=1, bits=True)
        matialvarezs_charge_controller_utils.create_registers_data(code='pv_voltage_input', address=0x3100, count=1,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)

        matialvarezs_charge_controller_utils.create_registers_data(code='pv_current_input', address=0x3101, count=1,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)

        matialvarezs_charge_controller_utils.create_registers_data(code='pv_power_input', address=0x3102, count=2,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)

        matialvarezs_charge_controller_utils.create_registers_data(code='batery_voltage', address=0x331A, count=1,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='batery_current', address=0x331B, count=2,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='batery_current_charge', address=0x311A,
                                                                   count=1, unit=1,
                                                                   function_code=0x04, times=1)  # % de carga
        matialvarezs_charge_controller_utils.create_registers_data(code='batery_temperature', address=0x3110, count=1,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='load_voltage', address=0x310C, count=1, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='load_current', address=0x310D, count=1, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='load_power', address=0x310E, count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='device_temperature', address=0x3111, count=1,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='consumed_energy_today', address=0x3304,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='consumed_energy_month', address=0x3306,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='consumed_energy_year', address=0x3308, count=2,
                                                                   unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='total_consumed_energy', address=0x330A,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='generated_energy_today', address=0x330C,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='generated_energy_month', address=0x330E,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='generated_energy_year', address=0x3310,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='total_generated_energy', address=0x3312,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)
        matialvarezs_charge_controller_utils.create_registers_data(code='carbon_dioxide_reduction', address=0x3314,
                                                                   count=2, unit=1,
                                                                   function_code=0x04, times=100)



from django import VERSION as DJANGO_VERSION

if DJANGO_VERSION >= (2, 0):
	from django.urls import include, path, re_path as url
else:
	from django.conf.urls import include, url


app_name = "matialvarezs_charge_controller_api"

urlpatterns = [
    url('v1/', include('matialvarezs_charge_controller.api.v1.urls', namespace='v1')),
]



from .decorators import api_v1_safe_request
from ohm2_handlers_light import utils as h_utils
from django.contrib.auth.models import User
import binascii
from . import errors as api_v1_errors
from matialvarezs_handlers_easy import crontab_jobs_utils
from matialvarezs_charge_controller import settings as matialvarezs_charge_controller_settings


@api_v1_safe_request
def create_crontab_job_get_data_charge_controller(request, params):
    # p = h_utils.cleaned(params, (
    #     ("string", "minutes_frecuency", 0),
    # ))
    command = matialvarezs_charge_controller_settings.SCRIPTS_PATH + 'charge_controller_send_data_to_server.sh >>' + matialvarezs_charge_controller_settings.CRON_JOB_LOGS_PATH + 'charge_controller_send_data_to_server.log 2>&1'
    comment = ''
    if matialvarezs_charge_controller_settings.PRODUCTION_CONFIG:
        comment = 'production_charge_controller_send_data_to_server'
    else:
        comment = 'development_charge_controller_send_data_to_server'
    crontab_jobs_utils.create_cron_execute_between_x_minutes(minutes=params['minutes_frecuency'],command=command, comment=comment)

    ret = {
        "error": None,
        "ret": True,
    }
    return ret

